aboutsummaryrefslogtreecommitdiff
path: root/scripts/run_demo.sh
diff options
context:
space:
mode:
Diffstat (limited to 'scripts/run_demo.sh')
-rwxr-xr-xscripts/run_demo.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/scripts/run_demo.sh b/scripts/run_demo.sh
index 5f54787..0ad462e 100755
--- a/scripts/run_demo.sh
+++ b/scripts/run_demo.sh
@@ -5,8 +5,8 @@ if [[ $# -gt 0 ]]; then
fi
for i in "${rep[@]}"; do
echo "starting replica $i"
- #valgrind --leak-check=full ./hotstuff-app --conf hotstuff-sec${i}.conf > log${i} 2>&1 &
- #gdb -ex r -ex bt -ex q --args ./hotstuff-app --conf hotstuff-sec${i}.conf > log${i} 2>&1 &
- ./hotstuff-app --conf hotstuff-sec${i}.conf > log${i} 2>&1 &
+ #valgrind --leak-check=full ./examples/hotstuff-app --conf hotstuff-sec${i}.conf > log${i} 2>&1 &
+ #gdb -ex r -ex bt -ex q --args ./examples/hotstuff-app --conf hotstuff-sec${i}.conf > log${i} 2>&1 &
+ ./examples/hotstuff-app --conf ./hotstuff-sec${i}.conf > log${i} 2>&1 &
done
wait